@@ -81,7 +81,7 @@ class RequestFull():
         pageField = params["pageField"]
         pageLenField = params["pageLenField"]
 
-        data = { pageField: 1, pageLenField: 100 }
+        data = { page: 1, pagelen: 100 }
 
         while (data[pageField] <= data[pageLenField]):
             # TODO: Criar loop para adicionar params e valores
